from django.contrib.sites.models import Site, RequestSite
from django.core.mail import mail_admins, EmailMultiAlternatives
from django.template.loader import render_to_string
from registration.models import RegistrationProfile
from registration import signals

from registration.backends.default.views import *


class RegistrationView(RegistrationView):

    def register(self, request, **cleaned_data):
        """
        Given a username, email address and password, register a new
        user account, which will initially be inactive.

        Along with the new ``User`` object, a new
        ``registration.models.RegistrationProfile`` will be created,
        tied to that ``User``, containing the activation key which
        will be used for this account.

        An email will be sent to the supplied email address; this
        email should contain an activation link. The email will be
        rendered using two templates. See the documentation for
        ``RegistrationProfile.send_activation_email()`` for
        information about these templates and the contexts provided to
        them.

        After the ``User`` and ``RegistrationProfile`` are created and
        the activation email is sent, the signal
        ``registration.signals.user_registered`` will be sent, with
        the new ``User`` as the keyword argument ``user`` and the
        class of this backend as the sender.

        """
        username, email, password = cleaned_data['username'], cleaned_data['email'], cleaned_data['password1']
        if Site._meta.installed:
            site = Site.objects.get_current()
        else:
            site = RequestSite(request)
        new_user = RegistrationProfile.objects.create_inactive_user(username, email,
                                                                    password, site, send_email=False)

        ctx_dict = {'activation_key': new_user.registrationprofile_set.all()[0].activation_key,
                    'expiration_days': settings.ACCOUNT_ACTIVATION_DAYS,
                    'user': new_user,
                    'site': site}
        mail_admins('Activation request from %s for %s' % (email,site),'activation request',
                    html_message=render_to_string('registration/activation_request.txt', ctx_dict) % site,)
        signals.user_registered.send(sender=self.__class__,
                                     user=new_user,
                                     request=request)

        return new_user


def send_mail_activated(sender, user, **kwargs):
    to_list = [user.email,]
    from_email = settings.DEFAULT_FROM_EMAIL
    subject = 'Your account on for rain4food.net was activated.'
    ctx_dict = {'user': user,}
    text_content = subject
    html_content = render_to_string('registration/activation_email_complete.html', ctx_dict)
    msg = EmailMultiAlternatives(subject, text_content, from_email, to_list)
    msg.attach_alternative(html_content, "text/html")
    msg.send(fail_silently=False)

signals.user_activated.connect(send_mail_activated, dispatch_uid="send_mail_activated")
